# handymatt

A collection of custom libraries that I use in many of my Python projects!

## Libraries
- `JsonHandler`: 
- `StringParser`: 
- `BookmarksGetter`: 
- `wsl_paths`: functions for handling conversion between Windows and WSL filepaths

## Libraries to add:
- `sqlite_api`: 
- `file_tag_manager`: library for reading/writing file tags to json files in the file directories
